PrayerTimeModel class

Available extensions

Constructors

PrayerTimeModel({required int day, required int month, required String fajr, required String sunrise, required String dhuhr, required String asr, required String maghrib, required String isha})
PrayerTimeModel.fromJson(Map json)
factory

Properties

asr → String
final
asr12h → String

Available on PrayerTimeModel, provided by the PrayerTimeExtensions extension

no setter
day → int
final
dhuhr → String
final
dhuhr12h → String

Available on PrayerTimeModel, provided by the PrayerTimeExtensions extension

no setter
fajr → String
final
fajr12h → String

Available on PrayerTimeModel, provided by the PrayerTimeExtensions extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
isha → String
final
isha12h → String

Available on PrayerTimeModel, provided by the PrayerTimeExtensions extension

no setter
maghrib → String
final
maghrib12h → String

Available on PrayerTimeModel, provided by the PrayerTimeExtensions extension

no setter
month → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sunrise → String
final
sunrise12h → String

Available on PrayerTimeModel, provided by the PrayerTimeExtensions extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited